@@ -1,4 +1,3 @@
-from pynonymizer.database.provider import DatabaseProvider
 from pynonymizer.database.provider import SEED_TABLE_NAME
 from pynonymizer.strategy.update_column import UpdateColumnStrategyTypes
 from pynonymizer.strategy.table import TableStrategyTypes
@@ -11,10 +10,9 @@ from pynonymizer.fake import FakeDataType
 
 import math
 import logging
-from tqdm import tqdm
 from pathlib import PureWindowsPath, PurePosixPath
 import re
-
+from .connectionstring import ConnectionString
 
 _FAKE_COLUMN_TYPES = {
     FakeDataType.STRING: "VARCHAR(MAX)",
@@ -23,9 +21,6 @@ _FAKE_COLUMN_TYPES = {
     FakeDataType.INT: "INT",
 }
 
-_LOCAL_SERVER = "127.0.0.1"
-_DEFAULT_PORT = "1433"
-
 
 def _extract_driver_version(driver):
     try:
@@ -34,7 +29,7 @@ def _extract_driver_version(driver):
         return 0
 
 
-class MsSqlProvider(DatabaseProvider):
+class MsSqlProvider:
     """
     A pyodbc-based MSSQL provider.
     """
@@ -53,29 +48,47 @@ class MsSqlProvider(DatabaseProvider):
         db_pass,
         db_name,
         seed_rows,
+        progress,
         db_port=None,
+        connection_string=None,
         backup_compression=False,
         driver=None,
     ):
         # import here for fast-failiness
         import pyodbc
 
-        db_host = db_host or _LOCAL_SERVER
-        db_port = db_port or _DEFAULT_PORT
-        driver = driver or self.__detect_driver()
+        self.connnectionstr = ConnectionString.from_string(connection_string or "")
 
-        self.db_host = db_host
-        self.db_user = db_user
-        self.db_pass = db_pass
-        self.db_name = db_name
-        self.db_port = db_port
+        if db_name is None:
+            raise ValueError("db_name is required")
+        else:
+            self.db_name = db_name
+
+        if db_host and db_host.startswith(r"(local)\\"):
+            self.connnectionstr["server"] = db_host
+        else:
+            db_host = "(local)"
+            if db_port:
+                self.connnectionstr["server"] = f"{db_host},{db_port}"
+            else:
+                self.connnectionstr["server"] = db_host
+
+        if db_user:
+            self.connnectionstr["uid"] = db_user
+
+        if db_pass:
+            self.connnectionstr["pwd"] = db_pass
+
+        self.progress = progress
+
+        if "driver" not in self.connnectionstr:
+            self.connnectionstr["driver"] = driver or self.__detect_driver()
 
         self.seed_rows = int(seed_rows)
 
         self.__conn = None
         self.__db_conn = None
         self.__backup_compression = backup_compression
-        self.__driver = driver
 
     def __detect_driver(self):
         import pyodbc
@@ -92,25 +105,13 @@ class MsSqlProvider(DatabaseProvider):
         # Sort by the highest number (like, ODBC driver 14 for SQL server)
         return sorted(ms_drivers, key=_extract_driver_version, reverse=True)[0]
 
-    def __require_local_server(self):
-        if self.db_host != _LOCAL_SERVER:
-            raise DependencyError(
-                "db_host",
-                "This operation does not support remote servers due to backup file "
-                "location requirements. You must omit db_host from your configuration "
-                "and run pynonymizer on the same server as the database.",
-            )
-
     def __connection(self):
         import pyodbc
 
         """a lazy-evaluated connection"""
         if self.__conn is None:
             self.__conn = pyodbc.connect(
-                driver=f"{{{self.__driver}}}",
-                server=f"{self.db_host},{self.db_port}",
-                uid=self.db_user,
-                pwd=self.db_pass,
+                self.connnectionstr.get_string(),
                 autocommit=True,
             )
 
@@ -122,11 +123,8 @@ class MsSqlProvider(DatabaseProvider):
         """a lazy-evaluated db-specific connection"""
         if self.__db_conn is None:
             self.__db_conn = pyodbc.connect(
-                driver=f"{{{self.__driver}}}",
+                self.connnectionstr.get_string(),
                 database=self.db_name,
-                server=f"{self.db_host},{self.db_port}",
-                uid=self.db_user,
-                pwd=self.db_pass,
                 autocommit=True,
             )
 
@@ -217,7 +215,9 @@ class MsSqlProvider(DatabaseProvider):
         # With STATS=x, we should recieve 100/x resultsets, provided the backup is slow enough.
         # With some databases, it will jump from y% to 100, so we'll only get <x nextset calls.
         # Even SSMS doesn't get informed (read: it's not my fault, blame microsoft)
-        with tqdm(desc=desc, total=math.floor(100 / self.__STATS)) as progressbar:
+        with self.progress(
+            desc=desc, total=math.floor(100 / self.__STATS)
+        ) as progressbar:
             while cursor.nextset():
                 progressbar.update()
 
@@ -266,7 +266,7 @@ class MsSqlProvider(DatabaseProvider):
         self.__db_execute(statement, value_list)
 
     def __seed(self, qualifier_map):
-        for i in tqdm(
+        for i in self.progress(
             range(0, self.seed_rows), desc="Inserting seed data", unit="rows"
         ):
             self.__insert_seed_row(qualifier_map)
@@ -275,9 +275,9 @@ class MsSqlProvider(DatabaseProvider):
         if column_strategy.strategy_type == UpdateColumnStrategyTypes.EMPTY:
             return "('')"
         elif column_strategy.strategy_type == UpdateColumnStrategyTypes.UNIQUE_EMAIL:
-            return f"( SELECT CONCAT(NEWID(), '@', NEWID(), '.com') )"
+            return f"( SELECT CONCAT(convert(varchar(38),NEWID()), '@example.com') )"
         elif column_strategy.strategy_type == UpdateColumnStrategyTypes.UNIQUE_LOGIN:
-            return f"( SELECT NEWID() )"
+            return f"( SELECT convert(varchar(38),NEWID()) )"
         elif column_strategy.strategy_type == UpdateColumnStrategyTypes.FAKE_UPDATE:
             column = f"[{column_strategy.qualifier}]"
             if column_strategy.sql_type:
@@ -318,7 +318,7 @@ class MsSqlProvider(DatabaseProvider):
 
         anonymization_errors = []
 
-        with tqdm(
+        with self.progress(
             desc="Anonymizing database", total=len(table_strategies)
         ) as progressbar:
             for table_strategy in table_strategies:
@@ -366,9 +366,11 @@ class MsSqlProvider(DatabaseProvider):
                                     table_name, i + 1, total_wheres
                                 )
                             )
-                            # Disable ANSI_WARNINGS to allow oversized fake data to be truncated without error
+
+                            # set ansi warnings off because otherwise we run into lots of little incompatibilities between the seed data nd the columns
+                            # e.g. string or binary data would be truncated (when the data is too long)
                             self.__db_execute(
-                                "SET ANSI_WARNINGS off; UPDATE {}[{}] SET {}{}; SET ANSI_WARNINGS on;".format(
+                                "SET ANSI_WARNINGS OFF; UPDATE {}[{}] SET {}{}; SET ANSI_WARNINGS ON; ".format(
                                     schema_prefix,
                                     table_name,
                                     column_assignments,
@@ -388,7 +390,7 @@ class MsSqlProvider(DatabaseProvider):
                 progressbar.update()
 
         if len(anonymization_errors) > 0:
-            raise Exception("Error during anonymization")
+            raise Exception("Error during anonymization" + repr(anonymization_errors))
 
         self.__run_scripts(database_strategy.after_scripts, "after")
 
@@ -396,8 +398,6 @@ class MsSqlProvider(DatabaseProvider):
         self.__drop_seed_table()
 
     def restore_database(self, input_path):
-        self.__require_local_server()
-
         move_files = self.__get_file_moves(input_path)
 
         self.logger.info("Found %d files in %s", len(move_files), input_path)
@@ -415,8 +415,6 @@ class MsSqlProvider(DatabaseProvider):
         self.__async_operation_progress("Restoring Database", restore_cursor)
 
     def dump_database(self, output_path):
-        self.__require_local_server()
-
         with_options = []
         if self.__backup_compression:
             with_options.append("COMPRESSION")
