@@ -1,15 +1,14 @@
-from tqdm import tqdm
 from time import sleep
 import logging
-from pynonymizer.database.provider import DatabaseProvider, SEED_TABLE_NAME
+from pynonymizer.database.input import resolve_input
+from pynonymizer.database.output import resolve_output
+from pynonymizer.database.provider import SEED_TABLE_NAME
 from pynonymizer.database.exceptions import UnsupportedTableStrategyError
 from pynonymizer.database.mysql import execution, query_factory
-from pynonymizer.database.basic.input import resolve_input
-from pynonymizer.database.basic.output import resolve_output
 from pynonymizer.strategy.table import TableStrategyTypes
 
 
-class MySqlProvider(DatabaseProvider):
+class MySqlProvider:
     """
     A command-line based mysql provider. Uses `mysql` and `mysqldump`,
     Because of the efficiency of piping mass amounts of sql into the command-line client.
@@ -27,6 +26,7 @@ class MySqlProvider(DatabaseProvider):
         db_pass,
         db_name,
         seed_rows,
+        progress,
         db_port=None,
         cmd_opts=None,
         dump_opts=None,
@@ -45,6 +45,7 @@ class MySqlProvider(DatabaseProvider):
         self.db_pass = db_pass
         self.db_name = db_name
         self.db_port = db_port
+        self.progress = progress
 
         self.seed_rows = int(seed_rows)
 
@@ -59,7 +60,7 @@ class MySqlProvider(DatabaseProvider):
         """
         'Seed' the database with a bunch of pre-generated random records so updates can be performed in batch updates
         """
-        for i in tqdm(
+        for i in self.progress(
             range(0, self.seed_rows), desc="Inserting seed data", unit="rows"
         ):
             self.logger.debug(f"Inserting seed row {i}")
@@ -122,7 +123,7 @@ class MySqlProvider(DatabaseProvider):
 
         anonymization_errors = []
 
-        with tqdm(
+        with self.progress(
             desc="Anonymizing database", total=len(table_strategies)
         ) as progressbar:
             for table_strategy in table_strategies:
@@ -172,7 +173,7 @@ class MySqlProvider(DatabaseProvider):
                 progressbar.update()
 
         if len(anonymization_errors) > 0:
-            raise Exception("Error during anonymization")
+            raise Exception("Error during anonymization" + repr(anonymization_errors))
 
         self.__run_scripts(database_strategy.after_scripts, "after")
 
@@ -196,7 +197,7 @@ class MySqlProvider(DatabaseProvider):
         try:
             batch_processor = self.__runner.open_batch_processor()
             with input_obj.open() as dumpfile_data:
-                with tqdm(
+                with self.progress(
                     desc="Restoring",
                     total=dumpsize,
                     unit="B",
@@ -221,7 +222,7 @@ class MySqlProvider(DatabaseProvider):
 
         dump_process = self.__dumper.open_dumper()
         with output_obj.open() as output_file:
-            with tqdm(
+            with self.progress(
                 desc="Dumping",
                 total=dumpsize_estimate,
                 unit="B",
