@@ -1,15 +1,13 @@
 from pynonymizer.database.provider import SEED_TABLE_NAME
-from tqdm import tqdm
 import logging
-from pynonymizer.database.provider import DatabaseProvider
 from pynonymizer.database.exceptions import UnsupportedTableStrategyError
 from pynonymizer.database.postgres import execution, query_factory
-from pynonymizer.database.basic.input import resolve_input
-from pynonymizer.database.basic.output import resolve_output
+from pynonymizer.database.input import resolve_input
+from pynonymizer.database.output import resolve_output
 from pynonymizer.strategy.table import TableStrategyTypes
 
 
-class PostgreSqlProvider(DatabaseProvider):
+class PostgreSqlProvider:
     """
     A command-line based postgres provider. Uses `psql` and `pg_dump`,
     because of the efficiency of piping mass amounts of sql into the command-line client.
@@ -26,6 +24,7 @@ class PostgreSqlProvider(DatabaseProvider):
         db_pass,
         db_name,
         seed_rows,
+        progress,
         db_port=None,
         cmd_opts=None,
         dump_opts=None,
@@ -45,6 +44,7 @@ class PostgreSqlProvider(DatabaseProvider):
         self.db_pass = db_pass
         self.db_name = db_name
         self.db_port = db_port
+        self.progress = progress
 
         self.seed_rows = int(seed_rows)
 
@@ -69,7 +69,7 @@ class PostgreSqlProvider(DatabaseProvider):
         """
         'Seed' the database with a bunch of pre-generated random records so updates can be performed in batch updates
         """
-        for i in tqdm(
+        for i in self.progress(
             range(0, self.seed_rows), desc="Inserting seed data", unit="rows"
         ):
             self.logger.debug(f"Inserting seed row {i}")
@@ -132,7 +132,7 @@ class PostgreSqlProvider(DatabaseProvider):
 
         anonymization_errors = []
 
-        with tqdm(
+        with self.progress(
             desc="Anonymizing database", total=len(table_strategies)
         ) as progressbar:
             for table_strategy in table_strategies:
@@ -176,7 +176,7 @@ class PostgreSqlProvider(DatabaseProvider):
                 progressbar.update()
 
         if len(anonymization_errors) > 0:
-            raise Exception("Error during anonymization")
+            raise Exception("Error during anonymization" + repr(anonymization_errors))
 
         self.__run_scripts(database_strategy.after_scripts, "after")
 
@@ -195,7 +195,7 @@ class PostgreSqlProvider(DatabaseProvider):
         batch_processor = self.__runner.open_batch_processor()
         try:
             with input_obj.open() as dumpfile_data:
-                with tqdm(
+                with self.progress(
                     desc="Restoring",
                     total=dumpsize,
                     unit="B",
@@ -220,7 +220,7 @@ class PostgreSqlProvider(DatabaseProvider):
 
         dump_process = self.__dumper.open_dumper()
         with output_obj.open() as output_file:
-            with tqdm(
+            with self.progress(
                 desc="Dumping",
                 total=dumpsize_estimate,
                 unit="B",
