@@ -1,33 +1,35 @@
 import logging
-from pynonymizer.database import get_temp_db_name, get_provider
-from pynonymizer.fake import FakeColumnGenerator
+from pynonymizer.database.mssql import MsSqlProvider
+from pynonymizer.database.mysql import MySqlProvider
+from pynonymizer.database.postgres import PostgreSqlProvider
 from pynonymizer.strategy.parser import StrategyParser
 from pynonymizer.strategy.config import read_config
-from pynonymizer.exceptions import ArgumentValidationError, DatabaseConnectionError
-from pynonymizer.process_steps import StepActionMap, ProcessSteps
-
+from pynonymizer.exceptions import ArgumentValidationError
+from pynonymizer.process_steps import ProcessSteps
+import uuid
+import os
 
 logger = logging.getLogger(__name__)
 
 
+def get_temp_db_name(filename=None):
+    name, _ = os.path.splitext(os.path.basename(filename))
+    return f"{name}_{uuid.uuid4().hex}"
+
+
 def pynonymize(
+    progress,
+    actions,
+    db_type,
     input_path=None,
     strategyfile_path=None,
     output_path=None,
     db_user=None,
     db_password=None,
-    db_type=None,
     db_host=None,
     db_name=None,
     db_port=None,
-    fake_locale=None,
-    only_step=None,
-    start_at_step=None,
-    stop_at_step=None,
-    skip_steps=None,
     seed_rows=None,
-    dry_run=False,
-    verbose=False,
     ignore_anonymization_errors=False,
     **kwargs,
 ):
@@ -38,33 +40,6 @@ def pynonymize(
         ArgumentValidationError: used when kwargs are missing or unable to be auto-resolved.
 
     """
-    # Default and Normalize args
-    if only_step is not None:
-        only_step = ProcessSteps.from_value(only_step)
-
-    if start_at_step is None:
-        start_at_step = ProcessSteps.START
-    else:
-        start_at_step = ProcessSteps.from_value(start_at_step)
-
-    if stop_at_step is None:
-        stop_at_step = ProcessSteps.END
-    else:
-        stop_at_step = ProcessSteps.from_value(stop_at_step)
-
-    if skip_steps and len(skip_steps) > 0:
-        skip_steps = [ProcessSteps.from_value(skip) for skip in skip_steps]
-
-    if db_type is None:
-        db_type = "mysql"
-
-    actions = StepActionMap(
-        start_at_step=start_at_step,
-        stop_at_step=stop_at_step,
-        skip_steps=skip_steps,
-        dry_run=dry_run,
-        only_step=only_step,
-    )
 
     # Validate mandatory args (depends on step actions)
     validations = []
@@ -85,26 +60,20 @@ def pynonymize(
         if output_path is None:
             validations.append("Missing OUTPUT")
 
-    if db_user is None:
-        validations.append("Missing DB_USER")
-
-    if db_password is None:
-        validations.append("Missing DB_PASSWORD")
+    # do not validate db_user/password as these are managed by providers
+    # Mysql supports my.cnf files with additional config, so we have to assume db_host, db_user, db_password, db_port could all be in there
+    # postgres supports implicit db_pass using the .pgpass file
+    # mssql could be using integrated security or connectionstr
 
     if db_name is None:
         validations.append("Missing DB_NAME: Auto-resolve failed.")
 
-    if len(validations) > 0:
-        raise ArgumentValidationError(validations)
-
     # init strategy as it relies on I/O - fail fast here preferred to after restore
     if not actions.skipped(ProcessSteps.ANONYMIZE_DB):
-        strategy_parser = StrategyParser(fake_locale)
+        strategy_parser = StrategyParser()
 
         logger.debug("loading strategyfile %s...", strategyfile_path)
-        strategy = strategy_parser.parse_config(
-            read_config(strategyfile_path), locale_override=fake_locale
-        )
+        strategy = strategy_parser.parse_config(read_config(strategyfile_path))
 
     # Discover db-type kwargs
     # mssql_backup_option -> backup_option and pass these to the constructor
@@ -117,14 +86,27 @@ def pynonymize(
     logger.debug(
         "Database: (%s:%s)%s@%s name: %s", db_host, db_port, db_type, db_user, db_name
     )
-    db_provider = get_provider(
-        type=db_type,
+
+    if db_type == "mysql":
+        Provider = MySqlProvider
+    elif db_type == "postgres":
+        Provider = PostgreSqlProvider
+    elif db_type == "mssql":
+        Provider = MsSqlProvider
+    else:
+        validations.append(f"{db_type} is not a known database type.")
+
+    if len(validations) > 0:
+        raise ArgumentValidationError(validations)
+
+    db_provider = Provider(
         db_host=db_host,
         db_user=db_user,
         db_pass=db_password,
         db_name=db_name,
         db_port=db_port,
         seed_rows=seed_rows,
+        progress=progress,
         **db_kwargs,
     )
 
